@@ -13,12 +13,19 @@ class Prefs():
     try:
       f = open(os.path.expanduser("~")+"/.pygtkeditor",'r')
       self.prefs_dict = cPickle.load(f)
+      if not self.prefs_dict.has_key('auto_rotate'):
+        self.prefs_dict['auto_rotate']=True                 
+      if not self.prefs_dict.has_key('show_lines'):
+        self.prefs_dict['show_lines']=False
+      if not self.prefs_dict.has_key('indent'):
+        self.prefs_dict['indent']='  '
+          
     except:
       self.default()
       
   def default(self):
     self.prefs_dict['hildon_text_completion']=True
-    self.prefs_dict['default_language']='python'     
+    self.prefs_dict['default_language']='python'     ut
     self.prefs_dict['font_name']='Monospace'     
     self.prefs_dict['font_size']='12'     
     self.prefs_dict['auto_rotate']=True     
